==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { RectUtil } from "igniteui-angular-core";
import { PolyLineSegment } from "igniteui-angular-core";
import { PathFigure } from "igniteui-angular-core";
import { PathFigureCollection } from "igniteui-angular-core";
import { Flattener } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { boxArray$1, arrayShallowClone } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.sb = new ScatterFrame();
        _this.sd = new ScatterFrame();
        _this.r9 = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.cl.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.cl.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.sb.o = a;
        _this.sd.o = a;
        _this.r9.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.get_d4 = function () {
        return true;
    };
    ScatterLineSeries.prototype.by = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.gz = function () {
        if (!isNaN_(this.gy)) {
            return _super.prototype.gz.call(this);
        }
        return Defaults.x;
    };
    ScatterLineSeries.prototype.ez = function (a, b) {
        if (this.qo(a, b)) {
            return true;
        }
        if (this.vh(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.vh = function (a, b) {
        var c = this.b1;
        var d = c.dg;
        return this.e0(a, b, d.an);
    };
    ScatterLineSeries.prototype.ua = function (a, b) {
        var _this = this;
        _super.prototype.ua.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.bv;
        var d = b.bu;
        var e = this.getEffectiveViewport1(b);
        var f = this.fx * this.fx;
        var g = 0;
        if (this.sl != null) {
            g = this.sl.count;
        }
        if (this.sm != null) {
            g = Math.min(this.sm.count, g);
        }
        var h = new ScalerParams(0, c, d, this.r5.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.r5.e, e);
            $ret.b = _this.gg();
            return $ret;
        })());
        var j = arrayShallowClone(this.sl.asArray());
        var k = arrayShallowClone(this.sm.asArray());
        this.xAxis.hm(boxArray$1(j), 0, j.length, h);
        this.yAxis.hm(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.tb) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.vo(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.cl.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.tb) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.vo = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_su = function () {
        return true;
    };
    ScatterLineSeries.prototype.ul = function (a, b) {
        b.c4(false);
        _super.prototype.ul.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bu.left, b.bu.top, b.bu.width, b.bu.height);
        d = RectUtil.t(d, this.fy, this.fy);
        this.ue(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.si.az(this, this.sz(), runOn(this, this.rt));
        var f = false;
        var g = this.si.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.t6(-1, this.sl.count, b.q);
        }
        this.si.ad(e.dg, true, false, true, false);
        this.vm(e.dg, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.vg, this.fx);
    };
    ScatterLineSeries.prototype.vm = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.an = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.vl(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.vl(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.vi = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.vl = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.gy) ? f : 1;
            var h = this.vi(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.l9 = function (a, b, c, d) {
        _super.prototype.l9.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.mn(false);
                this.lu();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:vg:vn', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };

==> igniteui-angular-charts-17.0.0-beta.0.tgz: package/esm5/lib/ScatterLineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Point_$type, typeCast, runOn, Number_$type, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterLineSeriesView } from "./ScatterLineSeriesView";
import { Defaults } from "./Defaults";
import { PathGeometry } from "igniteui-angular-core";
import { Rect } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { Clipper } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { RectUtil } from "igniteui-angular-core";
import { PolyLineSegment } from "igniteui-angular-core";
import { PathFigure } from "igniteui-angular-core";
import { PathFigureCollection } from "igniteui-angular-core";
import { Flattener } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { boxArray$1, arrayShallowClone } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
var ScatterLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeries, _super);
    function ScatterLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterLineSeries.$;
        _this.sb = new ScatterFrame();
        _this.sd = new ScatterFrame();
        _this.r9 = new ScatterFrame();
        var a = function (b, c, d) {
            var e = _this.cl.indexOf(b.a);
            if (e == -1 || e == 0) {
                return b;
            }
            var f = _this.cl.item(e - 1);
            var g;
            if (!((function () { var h = c.g.tryGetValue(f, g); g = h.p1; return h.ret; })())) {
                return b;
            }
            return g;
        };
        _this.sb.o = a;
        _this.sd.o = a;
        _this.r9.o = a;
        return _this;
    }
    ScatterLineSeries.prototype.get_d4 = function () {
        return true;
    };
    ScatterLineSeries.prototype.by = function () {
        return new ScatterLineSeriesView(this);
    };
    ScatterLineSeries.prototype.gz = function () {
        if (!isNaN_(this.gy)) {
            return _super.prototype.gz.call(this);
        }
        return Defaults.x;
    };
    ScatterLineSeries.prototype.ez = function (a, b) {
        if (this.qo(a, b)) {
            return true;
        }
        if (this.vh(a, b)) {
            return true;
        }
        return false;
    };
    ScatterLineSeries.prototype.vh = function (a, b) {
        var c = this.b1;
        var d = c.dg;
        return this.e0(a, b, d.an);
    };
    ScatterLineSeries.prototype.ua = function (a, b) {
        var _this = this;
        _super.prototype.ua.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.bv;
        var d = b.bu;
        var e = this.getEffectiveViewport1(b);
        var f = this.fx * this.fx;
        var g = 0;
        if (this.sl != null) {
            g = this.sl.count;
        }
        if (this.sm != null) {
            g = Math.min(this.sm.count, g);
        }
        var h = new ScalerParams(0, c, d, this.r5.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.r5.e, e);
            $ret.b = _this.gg();
            return $ret;
        })());
        var j = arrayShallowClone(this.sl.asArray());
        var k = arrayShallowClone(this.sm.asArray());
        this.xAxis.hn(boxArray$1(j), 0, j.length, h);
        this.yAxis.hn(boxArray$1(k), 0, k.length, i);
        var l = d.top - 10;
        var m = d.bottom + 10;
        var n = d.left - 10;
        var o = d.right + 10;
        var p = ((function () {
            var $ret = new Clipper(1, n, m, o, l, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var q = 0; q < g;) {
            var r = q;
            ++q;
            if (g > this.tb) {
                while (q < g) {
                    var s = j[q] - j[r];
                    var t = k[q] - k[r];
                    var u = s * s + t * t;
                    if (u >= f) {
                        break;
                    }
                    ++q;
                }
                p.j(this.vo(j, k, r, q - 1));
            }
            else {
                var v = new OwnedPoint();
                v.c = { $type: Point_$type, x: j[r], y: k[r] };
                v.a = this.cl.item(r);
                if (!a.u.containsKey(v.a)) {
                    a.u.addItem(v.a, v);
                }
            }
        }
        if (g > this.tb) {
            p.i = null;
        }
    };
    ScatterLineSeries.prototype.vo = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a[c], y: b[c] };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a[h];
            f += b[h];
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterLineSeries.prototype.get_su = function () {
        return true;
    };
    ScatterLineSeries.prototype.ul = function (a, b) {
        b.c4(false);
        _super.prototype.ul.call(this, a, b);
        var c = this.getEffectiveViewport1(b);
        var d = new Rect(0, b.bu.left, b.bu.top, b.bu.width, b.bu.height);
        d = RectUtil.t(d, this.fy, this.fy);
        this.ue(a, new Clipper(0, d, false));
        var e = typeCast(ScatterLineSeriesView.$, b);
        this.si.az(this, this.sz(), runOn(this, this.rt));
        var f = false;
        var g = this.si.b;
        if (g != null) {
            f = true;
        }
        if (f) {
            this.t6(-1, this.sl.count, b.q);
        }
        this.si.ad(e.dg, true, false, true, false);
        this.vm(e.dg, a.m.count, function (h) { return a.m._inner[h].x; }, function (h) { return a.m._inner[h].y; }, this.vg, this.fx);
    };
    ScatterLineSeries.prototype.vm = function (a, b, c, d, e, f) {
        var g = new PathGeometry();
        a.an = g;
        g.c = new PathFigureCollection();
        var h = new List$1(PolyLineSegment.$, 0);
        var i = 0;
        for (var j = 0; j < b; j++) {
            if (isNaN_(c(j)) || isNaN_(d(j))) {
                var k = j - i;
                if (k > 0) {
                    if (e == 1 || h.count == 0) {
                        var l = new PolyLineSegment();
                        h.add(l);
                    }
                    this.vl(h._inner[h.count - 1]._points, i, j - 1, c, d, f);
                }
                i = j + 1;
            }
        }
        if (e == 1 || h.count == 0) {
            var m = new PolyLineSegment();
            h.add(m);
        }
        this.vl(h._inner[h.count - 1]._points, i, b - 1, c, d, f);
        var _loop_1 = function (n) {
            var o = h._inner[n];
            if (o._points.count > 0) {
                var p = ((function () {
                    var $ret = new PathFigure();
                    $ret.startPoint = o._points._inner[0];
                    return $ret;
                })());
                p._segments.add(o);
                g.c.add(p);
            }
        };
        for (var n = 0; n < h.count; n++) {
            _loop_1(n);
        }
    };
    ScatterLineSeries.prototype.vi = function (a, b, c, d, e, f) {
        var g = new List$1(Number_$type, 0);
        var h = d;
        var i = e;
        var j = i - h + 1;
        while (j > 0) {
            if (j <= 512) {
                Flattener.c(g, b, c, h, i, f);
                h = i + 1;
            }
            else {
                var k = h + 512 - 1;
                Flattener.c(g, b, c, h, k, f);
                h = k + 1;
            }
            j = i - h + 1;
        }
        return g;
    };
    ScatterLineSeries.prototype.vl = function (a, b, c, d, e, f) {
        if (c > -1) {
            var g = !isNaN_(this.gy) ? f : 1;
            var h = this.vi(new List$1(Number_$type, 0), d, e, b, c, g);
            var i = void 0;
            for (var j = 0; j < h.count; j++) {
                i = h.item(j);
                a.add({ $type: Point_$type, x: d(i), y: e(i) });
            }
        }
    };
    ScatterLineSeries.prototype.l9 = function (a, b, c, d) {
        _super.prototype.l9.call(this, a, b, c, d);
        switch (b) {
            case ScatterLineSeries.$$p[0]:
                this.mn(false);
                this.lu();
                break;
        }
    };
    ScatterLineSeries.$t = markType(ScatterLineSeries, 'ScatterLineSeries', ScatterBase.$);
    ScatterLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:vg:vn', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return ScatterLineSeries;
}(ScatterBase));
export { ScatterLineSeries };
